package org.acme.spring.web;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class GreetingControllerIT extends GreetingControllerTest {

}
